/**
 * Copyright (C) 2021 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#define private public
#include "NfcTag.h"

bool isTestInProgress = false;

struct sigaction new_action, old_action;

void sigabrt_handler(int signum, siginfo_t* info, void* context) {
    if (isTestInProgress && info->si_signo == SIGABRT) {
        (*old_action.sa_sigaction)(signum, info, context);
        return;
    }
    exit(EXIT_FAILURE);
}

int main() {
    sigemptyset(&new_action.sa_mask);
    new_action.sa_flags = SA_SIGINFO;
    new_action.sa_sigaction = sigabrt_handler;
    sigaction(SIGABRT, &new_action, &old_action);

    NfcTag tag = {};
    tag.mTechListTail = NfcTag::MAX_NUM_TECHNOLOGY;
    tag.mNumTechList = NfcTag::MAX_NUM_TECHNOLOGY;
    tNFA_ACTIVATED activationData = {};
    isTestInProgress = true;
    tag.discoverTechnologies(activationData);
    isTestInProgress = false;
    return EXIT_SUCCESS;
}
